<?php

namespace App\Utils;

use App\Utils\SettingsUtils;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

/**
 * class used to make requests to vitalpbx api
 */
class VitalPBXApiUtils
{
    public static function request(
        $path,
        $tenant = null,
        $method = 'GET',
        $params = null,
        $settings = null,
        $timeout = 30,
        $query = null
    )
    {
        //checks if settings are null and returns error message
        if (is_null($settings) && ! SettingsUtils::pbxSettingsSet()) {
            return response()->json(['message' => __('pbx_empty_settings')], 422);
        }

        $settings = $settings ?? SettingsUtils::getPbxSettings();

        $protocol = (bool) $settings['secure'] === true ? 'https' : 'http';

        $url = "{$protocol}://{$settings['host']}:{$settings['port']}/api/v2/{$path}";
        $headers = ['app-key' => $settings['app_key'], 'tenant' => $tenant];

        //tenant uri requires dynamic segment and no tenant header
        if ($path == 'tenants' && $tenant != '1') {
            if (isset($tenant)) $url = "{$url}/{$tenant}";
            unset($headers['tenant']);
        }

        $options = ['verify' => false];

        if (!is_null($query)) {
            $options['query'] = $query;
        }

        $response = match($method) {
            'GET' => Http::withOptions($options)
                ->withHeaders($headers)
                ->timeout($timeout)
                ->get($url),
            'POST' => Http::withOptions($options)
                ->withHeaders($headers)
                ->timeout($timeout)
                ->post($url, $params),
            'PUT' => Http::withOptions($options)->withHeaders($headers)->put($url, $params),
            'UPDATE' => Http::withHeaders($headers)->send(
				'UPDATE',
				$url,
	            $options
            ),
            'DELETE' => Http::withOptions($options)->withHeaders($headers)->delete($url),
        };
        if ($response->successful()) return ['data' => $response->json()['data']];
        return response()->json(['message' => $response->json()['message']], 422);
    }

    static public function checkEmptySettings($websocket = null)
    {
        if (! SettingsUtils::pbxSettingsSet()) {
            $message = __('pbx_empty_settings');

            if (isset($websocket)) {
                return ['message' => $message,
                    'event' => 'search_contact', 'error' => true
                ];
            } else {
                return response()->json(['message' => $message], 422);
            }
        }
    }

    public static function checkAppKeyFile()
    {
        $filePath = '/etc/vitalpbx/vitalpbx-maint.conf';

        if (is_file($filePath)) {
            return trim(file_get_contents($filePath));
        }

        return false;
    }
}
